@@ -1,6 +1,6 @@
 /***********************************************************************/
 /*                                                                     */
-/*                           Objective Caml                            */
+/*                                OCaml                                */
 /*                                                                     */
 /*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         */
 /*                                                                     */
@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: fail.h 9030 2008-09-18 11:23:28Z xleroy $ */
+/* $Id: fail.h 12000 2012-01-07 20:55:28Z lefessan $ */
 
 #ifndef CAML_FAIL_H
 #define CAML_FAIL_H
@@ -24,6 +24,10 @@
 #include "mlvalues.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 CAMLextern void caml_raise (value bucket) Noreturn;
 CAMLextern void caml_raise_constant (value tag) Noreturn;
 CAMLextern void caml_raise_with_arg (value tag, value arg) Noreturn;
@@ -41,4 +45,8 @@ CAMLextern void caml_init_exceptions (void);
 CAMLextern void caml_array_bound_error (void) Noreturn;
 CAMLextern void caml_raise_sys_blocked_io (void) Noreturn;
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* CAML_FAIL_H */
