@@ -1,6 +1,6 @@
 /***********************************************************************/
 /*                                                                     */
-/*                           Objective Caml                            */
+/*                                OCaml                                */
 /*                                                                     */
 /*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         */
 /*                                                                     */
@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: intext.h 7064 2005-09-22 14:21:50Z xleroy $ */
+/* $Id: intext.h 12227 2012-03-13 14:44:48Z xleroy $ */
 
 /* Structured input/output */
 
@@ -25,6 +25,10 @@
 #include "mlvalues.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 CAMLextern void caml_output_value_to_malloc(value v, value flags,
                                             /*out*/ char ** buf,
                                             /*out*/ intnat * len);
@@ -40,7 +44,7 @@ CAMLextern intnat caml_output_value_to_block(value v, value flags,
 
 
 CAMLextern value caml_input_val_from_string (value str, intnat ofs);
-  /* Read a structured value from the Caml string [str], starting
+  /* Read a structured value from the OCaml string [str], starting
      at offset [ofs]. */
 CAMLextern value caml_input_value_from_malloc(char * data, intnat ofs);
   /* Read a structured value from a malloced buffer.  [data] points
@@ -85,4 +89,8 @@ CAMLextern void caml_deserialize_block_float_8(void * data, intnat len);
 CAMLextern void caml_deserialize_error(char * msg);
 
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* CAML_INTEXT_H */
