@@ -1,6 +1,6 @@
 /***********************************************************************/
 /*                                                                     */
-/*                           Objective Caml                            */
+/*                                OCaml                                */
 /*                                                                     */
 /*             Damien Doligez, projet Para, INRIA Rocquencourt         */
 /*                                                                     */
@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: memory.h 9153 2008-12-03 18:09:09Z doligez $ */
+/* $Id: memory.h 12210 2012-03-08 19:52:03Z doligez $ */
 
 /* Allocation macros and functions */
 
@@ -25,6 +25,11 @@
 #include "misc.h"
 #include "mlvalues.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
 CAMLextern value caml_alloc_shr (mlsize_t, tag_t);
 CAMLextern void caml_adjust_gc_speed (mlsize_t, mlsize_t);
 CAMLextern void caml_alloc_dependent_memory (mlsize_t);
@@ -68,15 +73,15 @@ CAMLextern struct caml__roots_block *caml_local_roots;  /* defined in roots.c */
 
    If you need local variables of type [value], declare them with one
    or more calls to the [CAMLlocal] macros at the beginning of the
-   function. Use [CAMLlocalN] (at the beginning of the function) to
-   declare an array of [value]s.
+   function, after the call to CAMLparam.  Use [CAMLlocalN] (at the
+   beginning of the function) to declare an array of [value]s.
 
    Your function may raise an exception or return a [value] with the
    [CAMLreturn] macro.  Its argument is simply the [value] returned by
    your function.  Do NOT directly return a [value] with the [return]
    keyword.  If your function returns void, use [CAMLreturn0].
 
-   All the identifiers beginning with "caml__" are reserved by Caml.
+   All the identifiers beginning with "caml__" are reserved by OCaml.
    Do not use them for anything (local or global variables, struct or
    union tags, macros, etc.)
 */
@@ -241,7 +246,7 @@ CAMLextern struct caml__roots_block *caml_local_roots;  /* defined in roots.c */
    It must contain all values in C local variables and function parameters
    at the time the minor GC is called.
    Usage:
-   After initialising your local variables to legal Caml values, but before
+   After initialising your local variables to legal OCaml values, but before
    calling allocation functions, insert [Begin_roots_n(v1, ... vn)], where
    v1 ... vn are your variables of type [value] that you want to be updated
    across allocations.
@@ -335,7 +340,7 @@ CAMLextern void caml_remove_global_root (value *);
    the value of this variable, it must do so by calling
    [caml_modify_generational_global_root].  The [value *] pointer
    passed to [caml_register_generational_global_root] must contain
-   a valid Caml value before the call.
+   a valid OCaml value before the call.
    In return for these constraints, scanning of memory roots during
    minor collection is made more efficient. */
 
@@ -356,4 +361,8 @@ CAMLextern void caml_remove_generational_global_root (value *);
 
 CAMLextern void caml_modify_generational_global_root(value *r, value newval);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* CAML_MEMORY_H */
