@@ -1,6 +1,6 @@
 /***********************************************************************/
 /*                                                                     */
-/*                           Objective Caml                            */
+/*                                OCaml                                */
 /*                                                                     */
 /*         Xavier Leroy and Damien Doligez, INRIA Rocquencourt         */
 /*                                                                     */
@@ -11,7 +11,7 @@
 /*                                                                     */
 /***********************************************************************/
 
-/* $Id: signals.h 7904 2007-02-23 09:29:45Z xleroy $ */
+/* $Id: signals.h 12000 2012-01-07 20:55:28Z lefessan $ */
 
 #ifndef CAML_SIGNALS_H
 #define CAML_SIGNALS_H
@@ -22,9 +22,17 @@
 #include "misc.h"
 #include "mlvalues.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 
 CAMLextern void caml_enter_blocking_section (void);
 CAMLextern void caml_leave_blocking_section (void);
 
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* CAML_SIGNALS_H */
