@@ -1,6 +1,6 @@
 (***********************************************************************)
 (*                                                                     *)
-(*                           Objective Caml                            *)
+(*                                OCaml                                *)
 (*                                                                     *)
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: char.mli 7164 2005-10-25 18:34:07Z doligez $ *)
+(* $Id: char.mli 12241 2012-03-14 14:32:07Z doligez $ *)
 
 (** Character operations. *)
 
@@ -26,7 +26,7 @@ val chr : int -> char
 val escaped : char -> string
 (** Return a string representing the given character,
    with special characters escaped following the lexical conventions
-   of Objective Caml. *)
+   of OCaml. *)
 
 val lowercase : char -> char
 (** Convert the given character to its equivalent lowercase character. *)
@@ -45,4 +45,6 @@ val compare: t -> t -> int
 
 (**/**)
 
+(* The following is for system use only. Do not call directly. *)
+
 external unsafe_chr : int -> char = "%identity"
