@@ -1,6 +1,6 @@
 (***********************************************************************)
 (*                                                                     *)
-(*                           Objective Caml                            *)
+(*                                OCaml                                *)
 (*                                                                     *)
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: int64.ml,v 1.9 2002/06/26 09:13:58 xleroy Exp $ *)
+(* $Id: int64.ml 11156 2011-07-27 14:17:02Z doligez $ *)
 
 (* Module [Int64]: 64-bit integers *)
 
@@ -29,33 +29,31 @@ external shift_right : int64 -> int -> int64 = "%int64_asr"
 external shift_right_logical : int64 -> int -> int64 = "%int64_lsr"
 external of_int : int -> int64 = "%int64_of_int"
 external to_int : int64 -> int = "%int64_to_int"
-external of_float : float -> int64 = "int64_of_float"
-external to_float : int64 -> float = "int64_to_float"
+external of_float : float -> int64 = "caml_int64_of_float"
+external to_float : int64 -> float = "caml_int64_to_float"
 external of_int32 : int32 -> int64 = "%int64_of_int32"
 external to_int32 : int64 -> int32 = "%int64_to_int32"
 external of_nativeint : nativeint -> int64 = "%int64_of_nativeint"
 external to_nativeint : int64 -> nativeint = "%int64_to_nativeint"
 
-let zero = try of_int 0 with Invalid_argument _ -> Obj.magic Int32.zero
-let one = try of_int 1 with Invalid_argument _ -> Obj.magic Int32.one
-let minus_one = try of_int (-1) with Invalid_argument _ -> Obj.magic Int32.minus_one
-let succ n = add n one
-let pred n = sub n one
-let abs n = if n >= zero then n else neg n
-let min_int =
-  try shift_left one 63 with Invalid_argument _ -> Obj.magic Int32.min_int
-let max_int =
-  try sub min_int one with Invalid_argument _ -> Obj.magic Int32.max_int
-let lognot n = logxor n minus_one
+let zero = 0L
+let one = 1L
+let minus_one = -1L
+let succ n = add n 1L
+let pred n = sub n 1L
+let abs n = if n >= 0L then n else neg n
+let min_int = 0x8000000000000000L
+let max_int = 0x7FFFFFFFFFFFFFFFL
+let lognot n = logxor n (-1L)
 
-external format : string -> int64 -> string = "int64_format"
+external format : string -> int64 -> string = "caml_int64_format"
 let to_string n = format "%d" n
 
-external of_string : string -> int64 = "int64_of_string"
+external of_string : string -> int64 = "caml_int64_of_string"
 
-external bits_of_float : float -> int64 = "int64_bits_of_float"
-external float_of_bits : int64 -> float = "int64_float_of_bits"
+external bits_of_float : float -> int64 = "caml_int64_bits_of_float"
+external float_of_bits : int64 -> float = "caml_int64_float_of_bits"
 
 type t = int64
 
-let compare = (Pervasives.compare: t -> t -> int)
+let compare (x: t) (y: t) = Pervasives.compare x y
