@@ -1,6 +1,6 @@
 (***********************************************************************)
 (*                                                                     *)
-(*                           Objective Caml                            *)
+(*                                OCaml                                *)
 (*                                                                     *)
 (*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
 (*                                                                     *)
@@ -11,7 +11,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: list.ml,v 1.32 2005/10/25 18:34:07 doligez Exp $ *)
+(* $Id: list.ml 11156 2011-07-27 14:17:02Z doligez $ *)
 
 (* List operations *)
 
@@ -29,13 +29,13 @@ let tl = function
     [] -> failwith "tl"
   | a::l -> l
 
-let rec nth l n =
-  match l with
-    [] -> failwith "nth"
-  | a::l ->
-      if n = 0 then a else
-      if n > 0 then nth l (n-1) else
-      invalid_arg "List.nth"
+let nth l n =
+  if n < 0 then invalid_arg "List.nth" else
+  let rec nth_aux l n =
+    match l with
+    | [] -> failwith "nth"
+    | a::l -> if n = 0 then a else nth_aux l (n-1)
+  in nth_aux l n
 
 let append = (@)
 
@@ -56,6 +56,12 @@ let rec map f = function
     [] -> []
   | a::l -> let r = f a in r :: map f l
 
+let rec mapi i f = function
+    [] -> []
+  | a::l -> let r = f i a in r :: mapi (i + 1) f l
+
+let mapi f l = mapi 0 f l
+
 let rev_map f l =
   let rec rmap_f accu = function
     | [] -> accu
@@ -68,6 +74,12 @@ let rec iter f = function
     [] -> ()
   | a::l -> f a; iter f l
 
+let rec iteri i f = function
+    [] -> ()
+  | a::l -> f i a; iteri (i + 1) f l
+
+let iteri f l = iteri 0 f l
+
 let rec fold_left f accu l =
   match l with
     [] -> accu
